@@ -188,15 +188,6 @@ class ApplicationWindow(MApplicationWindow, Window):
             self._aui_manager.UnInit()
         super(ApplicationWindow, self).destroy()
 
-    ###########################################################################
-    # 'IWindow' interface.
-    ###########################################################################
-
-    def close(self):
-        if AUI:
-            self._aui_manager.UnInit()
-        super(ApplicationWindow, self).close()
-            
     ###########################################################################
     # Private interface.
     ###########################################################################
